@@ -3,6 +3,7 @@ import datetime
 from datetime import date
 import json
 import os
+from shutil import copyfile
 import textwrap
 
 from django.conf import settings
@@ -48,7 +49,13 @@ from souschef.meal.models import (
     Component_ingredient)
 from souschef.member.models import Client, Route, DeliveryHistory
 from souschef.order.models import (
-    Order, component_group_sorting, SIZE_CHOICES_REGULAR, SIZE_CHOICES_LARGE)
+    component_group_sorting,
+    ORDER_STATUS_CANCELLED,
+    ORDER_STATUS_ORDERED,
+    Order,
+    SIZE_CHOICES_LARGE,
+    SIZE_CHOICES_REGULAR,
+)
 from .filters import KitchenCountOrderFilter
 from .forms import DishIngredientsForm
 from . import tsp
@@ -58,16 +65,8 @@ LOGO_IMAGE = os.path.join(settings.BASE_DIR, "160widthSR-Logo-Screen-PurpleGreen
 DELIVERY_STARTING_POINT_LAT_LONG = (45.516564, -73.575145)  # Santropol Roulant
 
 
-class Orderlist(LoginRequiredMixin, PermissionRequiredMixin, FilterView):
-    # Display all the order on a given day
-    context_object_name = 'orders'
-    filterset_class = KitchenCountOrderFilter
-    model = Order
-    permission_required = 'sous_chef.read'
-    template_name = 'review_orders.html'
-
-    def get_queryset(self):
-        queryset = Order.objects.get_shippable_orders().order_by(
+def get_orders_for_kitchen_count(order_statuses):
+    return Order.objects.get_orders(order_statuses=order_statuses).order_by(
             'client__route__pk', 'pk'
         ).prefetch_related('orders').select_related(
             'client__member',
@@ -82,7 +81,36 @@ class Orderlist(LoginRequiredMixin, PermissionRequiredMixin, FilterView):
             'client__member__address__latitude',
             'client__member__address__longitude'
         )
-        return queryset
+
+
+def get_number_of_orders_in_status(orders, status):
+    return len([o for o in orders if o.status == status])
+
+
+def get_has_orders_in_status(orders, status):
+    return get_number_of_orders_in_status(orders, status) > 0
+
+
+def get_kitchen_count_context():
+    orders = get_orders_for_kitchen_count((ORDER_STATUS_ORDERED, ORDER_STATUS_CANCELLED))
+    return {
+        'orders': orders,
+        'has_ordered_orders': get_has_orders_in_status(orders, ORDER_STATUS_ORDERED),
+        'has_cancelled_orders': get_has_orders_in_status(orders, ORDER_STATUS_CANCELLED),
+        'nb_of_ordered_orders': get_number_of_orders_in_status(orders, ORDER_STATUS_ORDERED),
+    }
+
+
+class Orderlist(LoginRequiredMixin, PermissionRequiredMixin, FilterView):
+    # Display all the order on a given day
+    context_object_name = 'orders'
+    filterset_class = KitchenCountOrderFilter
+    model = Order
+    permission_required = 'sous_chef.read'
+    template_name = 'review_orders.html'
+
+    def get_queryset(self):
+        return get_orders_for_kitchen_count((ORDER_STATUS_ORDERED, ORDER_STATUS_CANCELLED))
 
     def get_context_data(self, **kwargs):
         context = super(Orderlist, self).get_context_data(**kwargs)
@@ -91,6 +119,14 @@ class Orderlist(LoginRequiredMixin, PermissionRequiredMixin, FilterView):
             log = LogEntry.objects.latest('action_time')
             context['orders_refresh_date'] = log
 
+        # See also get_kitchen_count_context, used for the "Generate orders" button.
+        context['has_ordered_orders'] = get_has_orders_in_status(
+            context['orders'], ORDER_STATUS_ORDERED)
+        context['has_cancelled_orders'] = get_has_orders_in_status(
+            context['orders'], ORDER_STATUS_CANCELLED)
+        context['nb_of_ordered_orders'] = get_number_of_orders_in_status(
+            context['orders'], ORDER_STATUS_ORDERED)
+        print(context)
         return context
 
 
@@ -783,9 +819,11 @@ class MultiRouteReport(object):
             # build full document
             doc.build(story,
                       onFirstPage=drawHeader, onLaterPages=drawHeader)
+            # Copy the route sheets file to keep a history
+            destination_of_copy = f"{settings.ROUTE_SHEETS_FILE.rstrip('.pdf')}_{datetime.date.today().strftime('%Y%m%d')}.pdf"
+            copyfile(settings.ROUTE_SHEETS_FILE, destination_of_copy)
             return doc.page  # number of last page
         # END def
-
         return go()  # returns number of pages generated
 
 # END Route sheet report.
@@ -1266,6 +1304,9 @@ def kcr_make_pages(date, component_lines, meal_lines):
 
         # build full document
         doc.build(story, onFirstPage=myFirstPage, onLaterPages=myLaterPages)
+        # Copy the kitchen count file to keep a history
+        destination_of_copy = f"{settings.KITCHEN_COUNT_FILE.rstrip('.pdf')}_{datetime.date.today().strftime('%Y%m%d')}.pdf"
+        copyfile(settings.KITCHEN_COUNT_FILE, destination_of_copy)
         return doc.page
     return go()  # returns number of pages generated
 
@@ -1533,6 +1574,9 @@ def kcr_make_labels(date, kitchen_list,
 
     if sheet.label_count > 0:
         sheet.save(settings.MEAL_LABELS_FILE)
+    # Copy the meal labels file to keep a history
+    destination_of_copy = f"{settings.MEAL_LABELS_FILE.rstrip('.pdf')}_{datetime.date.today().strftime('%Y%m%d')}.pdf"
+    copyfile(settings.MEAL_LABELS_FILE, destination_of_copy)
     return sheet.label_count
 
 # END Meal labels
@@ -1688,16 +1732,12 @@ class RefreshOrderView(
     def get(self, request):
         delivery_date = date.today()
         clients = Client.ongoing.all()
-        orders = Order.objects.auto_create_orders(delivery_date, clients)
+        Order.objects.auto_create_orders(delivery_date, clients)
         LogEntry.objects.log_action(
             user_id=1, content_type_id=1,
             object_id="", object_repr="Generation of orders for " + str(
                 datetime.datetime.now().strftime('%m %d %Y %H:%M')),
             action_flag=ADDITION,
         )
-        orders.sort(key=lambda o: (
-            o.client.route.pk if o.client.route is not None else -1,
-            o.pk
-        ))
-        context = {'orders': orders}
+        context = get_kitchen_count_context()
         return render(request, 'partials/generated_orders.html', context)
