@@ -50,8 +50,11 @@ RATE_TYPE_SOLIDARY = RATE_TYPE[2][0]
 PAYMENT_TYPE = (
     (' ', _('----')),
     ('3rd', _('3rd Party')),
+    ('cash', _('Cash')),
+    ('cheque', _('Cheque')),
     ('credit', _('Credit card')),
     ('eft', _('EFT')),
+    ('etransfert', _('e-Transfer')),
 )
 
 DELIVERY_TYPE = (
@@ -106,12 +109,12 @@ class Member(models.Model):
     # Member information
     firstname = models.CharField(
         max_length=50,
-        verbose_name=_('firstname')
+        verbose_name=_('First name')
     )
 
     lastname = models.CharField(
         max_length=50,
-        verbose_name=_('lastname')
+        verbose_name=_('Last name')
     )
 
     address = models.OneToOneField(
@@ -227,6 +230,7 @@ class Address(models.Model):
 
     class Meta:
         verbose_name_plural = _('addresses')
+        ordering = ['number', 'street', 'apartment']
 
     # Member address information
     number = models.PositiveIntegerField(
@@ -661,6 +665,14 @@ class Client(models.Model):
             age = today.year - self.birthdate.year - 1
         return age
 
+    @property
+    def status_verbose(self):
+        return dict(self.CLIENT_STATUS).get(self.status, _('Unknown'))
+
+    @property
+    def delivery_type_verbose(self):
+        return dict(DELIVERY_TYPE).get(self.delivery_type, _('Unknown'))
+
     @property
     def orders(self):
         """
@@ -668,6 +680,18 @@ class Client(models.Model):
         """
         return self.client_order.all()
 
+    def number_of_deliveries_in_month(self, year, month):
+        orders = self.client_order.filter(
+            status='D', delivery_date__year=year, delivery_date__month=month)
+        return len(orders)
+
+    @property
+    def upcoming_orders(self):
+        """
+        Returns upcoming orders associated to this client, regardless of order status.
+        """
+        return self.client_order.filter(delivery_date__gte=datetime.date.today()).all()
+
     @property
     def food_preparation(self):
         """
@@ -751,6 +775,21 @@ class Client(models.Model):
                     prefs.append((day, meal_schedule))
             return prefs
 
+    @property
+    def is_in_error_for_the_kitchen_count(self):
+        """ Return True if the client is in error for the Kitchen Count orders list page.
+
+        The client is in error if either:
+        - is not not geolocalized;
+        - it has no route;
+        - it is not active.
+        """
+        return (
+            not self.is_geolocalized or
+            not self.route or
+            self.status != 'A'
+        )
+
     def set_simple_meals_schedule(self, schedule):
         """
         Set the delivery days for the client.
