@@ -9,7 +9,7 @@ from django_filters import FilterSet, ChoiceFilter, CharFilter
 from django.urls import reverse
 from django.core.exceptions import ValidationError
 
-from souschef.member.models import (Client, DAYS_OF_WEEK, RATE_TYPE_LOW_INCOME,
+from souschef.member.models import (DAYS_OF_WEEK, RATE_TYPE_LOW_INCOME,
                            RATE_TYPE_SOLIDARY, OPTION_GROUP_CHOICES_PREPARATION)
 from souschef.meal.models import (COMPONENT_GROUP_CHOICES,
                          COMPONENT_GROUP_CHOICES_MAIN_DISH,
@@ -57,6 +57,19 @@ SIDE_PRICE_SOLIDARY = 0.50
 
 
 class OrderManager(models.Manager):
+    def get_orders(self,
+                   delivery_date=None,
+                   order_statuses=None):
+        # If no date is passed, use the current day
+        if delivery_date is None:
+            delivery_date = date.today()
+        extra_kwargs = {}
+        if order_statuses:
+            extra_kwargs['status__in'] = order_statuses
+        return self.get_queryset().filter(
+            delivery_date=delivery_date,
+            **extra_kwargs,
+        )
 
     def get_shippable_orders(self,
                              delivery_date=None,
@@ -76,7 +89,6 @@ class OrderManager(models.Manager):
         return self.get_queryset().filter(
             delivery_date=delivery_date,
             status=ORDER_STATUS_ORDERED,
-            client__status=Client.ACTIVE,
             **extra_kwargs)
 
     def get_shippable_orders_by_route(self,
@@ -99,7 +111,6 @@ class OrderManager(models.Manager):
             delivery_date=delivery_date,
             status=ORDER_STATUS_ORDERED,
             client__route=route_id,
-            client__status=Client.ACTIVE,
             **extra_kwargs)
 
     def get_billable_orders(self, year, month):
@@ -319,6 +330,7 @@ class OrderManager(models.Manager):
                     Order_item.objects.create(
                         order=order,
                         price=0,
+                        total_quantity=0,
                         billable_flag=False,
                         order_item_type=order_item_type)
 
@@ -619,7 +631,7 @@ class Order(models.Model):
                     size=None,
                     order_item_type="delivery",
                     remark=None,
-                    total_quantity=None,
+                    total_quantity=0,
                     component_group=None
                 )
         elif value is False:
@@ -1148,8 +1160,6 @@ class Order_item(models.Model):
 
     total_quantity = models.IntegerField(
         verbose_name=_('total quantity'),
-        null=True,
-        blank=True,
     )
 
     free_quantity = models.IntegerField(
